A purpose for each policy engine requiring such an integration. A single
policy engine may have multiple purposes defined, however a TagKey may only
specify a single purpose.
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
New values appearing in future releases of the client library, and
New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some
guidelines.
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Purpose for Compute Engine firewalls.
A corresponding purpose_data should be set for the network the tag is
intended for. The key should be network and the value should be in
either of these two formats: