#[non_exhaustive]pub struct ListProjectsRequest {
pub parent: String,
pub page_token: String,
pub page_size: i32,
pub show_deleted: bool,
/* private fields */
}Expand description
The request sent to the ListProjects method.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. The name of the parent resource whose projects are being listed. Only children of this parent resource are listed; descendants are not listed.
If the parent is a folder, use the value folders/{folder_id}. If the
parent is an organization, use the value organizations/{org_id}.
page_token: StringOptional. A pagination token returned from a previous call to [ListProjects] [google.cloud.resourcemanager.v3.Projects.ListProjects] that indicates from where listing should continue.
page_size: i32Optional. The maximum number of projects to return in the response. The server can return fewer projects than requested. If unspecified, server picks an appropriate default.
show_deleted: boolOptional. Indicate that projects in the DELETE_REQUESTED state should
also be returned. Normally only ACTIVE projects are returned.
Implementations
Sourceimpl ListProjectsRequest
impl ListProjectsRequest
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_page_token<T: Into<String>>(self, v: T) -> Self
pub fn set_page_token<T: Into<String>>(self, v: T) -> Self
Sets the value of page_token.
Example
let x = ListProjectsRequest::new().set_page_token("example");Sourcepub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
pub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
Sourcepub fn set_show_deleted<T: Into<bool>>(self, v: T) -> Self
pub fn set_show_deleted<T: Into<bool>>(self, v: T) -> Self
Sets the value of show_deleted.
Example
let x = ListProjectsRequest::new().set_show_deleted(true);Trait Implementations
Sourceimpl Clone for ListProjectsRequest
impl Clone for ListProjectsRequest
Sourcefn clone(&self) -> ListProjectsRequest
fn clone(&self) -> ListProjectsRequest
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for ListProjectsRequest
impl Debug for ListProjectsRequest
Sourceimpl Default for ListProjectsRequest
impl Default for ListProjectsRequest
Sourcefn default() -> ListProjectsRequest
fn default() -> ListProjectsRequest
Sourceimpl Message for ListProjectsRequest
impl Message for ListProjectsRequest
Sourceimpl PartialEq for ListProjectsRequest
impl PartialEq for ListProjectsRequest
impl StructuralPartialEq for ListProjectsRequest