#[non_exhaustive]pub struct Project {
pub name: String,
pub parent: String,
pub project_id: String,
pub state: State,
pub display_name: String,
pub create_time: Option<Timestamp>,
pub update_time: Option<Timestamp>,
pub delete_time: Option<Timestamp>,
pub etag: String,
pub labels: HashMap<String, String>,
/* private fields */
}Expand description
A project is a high-level Google Cloud entity. It is a container for ACLs, APIs, App Engine Apps, VMs, and other Google Cloud Platform resources.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringOutput only. The unique resource name of the project. It is an int64 generated number prefixed by “projects/”.
Example: projects/415104041262
parent: StringOptional. A reference to a parent Resource. eg., organizations/123 or
folders/876.
project_id: StringImmutable. The unique, user-assigned id of the project. It must be 6 to 30 lowercase ASCII letters, digits, or hyphens. It must start with a letter. Trailing hyphens are prohibited.
Example: tokyo-rain-123
state: StateOutput only. The project lifecycle state.
display_name: StringOptional. A user-assigned display name of the project. When present it must be between 4 to 30 characters. Allowed characters are: lowercase and uppercase letters, numbers, hyphen, single-quote, double-quote, space, and exclamation point.
Example: My Project
create_time: Option<Timestamp>Output only. Creation time.
update_time: Option<Timestamp>Output only. The most recent time this resource was modified.
delete_time: Option<Timestamp>Output only. The time at which this resource was requested for deletion.
etag: StringOutput only. A checksum computed by the server based on the current value of the Project resource. This may be sent on update and delete requests to ensure the client has an up-to-date value before proceeding.
labels: HashMap<String, String>Optional. The labels associated with this project.
Label keys must be between 1 and 63 characters long and must conform to the following regular expression: [a-z]([-a-z0-9]*[a-z0-9])?.
Label values must be between 0 and 63 characters long and must conform to the regular expression ([a-z]([-a-z0-9]*[a-z0-9])?)?.
No more than 64 labels can be associated with a given resource.
Clients should store labels in a representation such as JSON that does not depend on specific characters being disallowed.
Example: "myBusinessDimension" : "businessValue"
Implementations
Sourceimpl Project
impl Project
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_project_id<T: Into<String>>(self, v: T) -> Self
pub fn set_project_id<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_display_name<T: Into<String>>(self, v: T) -> Self
pub fn set_display_name<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_create_time<T>(self, v: T) -> Self
pub fn set_create_time<T>(self, v: T) -> Self
Sets the value of create_time.
Example
use wkt::Timestamp;
let x = Project::new().set_create_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of create_time.
Example
use wkt::Timestamp;
let x = Project::new().set_or_clear_create_time(Some(Timestamp::default()/* use setters */));
let x = Project::new().set_or_clear_create_time(None::<Timestamp>);Sourcepub fn set_update_time<T>(self, v: T) -> Self
pub fn set_update_time<T>(self, v: T) -> Self
Sets the value of update_time.
Example
use wkt::Timestamp;
let x = Project::new().set_update_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of update_time.
Example
use wkt::Timestamp;
let x = Project::new().set_or_clear_update_time(Some(Timestamp::default()/* use setters */));
let x = Project::new().set_or_clear_update_time(None::<Timestamp>);Sourcepub fn set_delete_time<T>(self, v: T) -> Self
pub fn set_delete_time<T>(self, v: T) -> Self
Sets the value of delete_time.
Example
use wkt::Timestamp;
let x = Project::new().set_delete_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_delete_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_delete_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of delete_time.
Example
use wkt::Timestamp;
let x = Project::new().set_or_clear_delete_time(Some(Timestamp::default()/* use setters */));
let x = Project::new().set_or_clear_delete_time(None::<Timestamp>);Trait Implementations
impl StructuralPartialEq for Project