#[non_exhaustive]pub struct SearchProjectsResponse {
pub projects: Vec<Project>,
pub next_page_token: String,
/* private fields */
}Expand description
A page of the response received from the SearchProjects method.
A paginated response where more pages are available has
next_page_token set. This token can be used in a subsequent request to
retrieve the next request page.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.projects: Vec<Project>The list of Projects that matched the list filter query. This list can be paginated.
next_page_token: StringPagination token.
If the result set is too large to fit in a single response, this token
is returned. It encodes the position of the current result cursor.
Feeding this value into a new list request with the page_token parameter
gives the next page of the results.
When next_page_token is not filled in, there is no next page and
the list returned is the last page in the result set.
Pagination tokens have a limited lifetime.
Implementations
Sourceimpl SearchProjectsResponse
impl SearchProjectsResponse
Sourcepub fn set_projects<T, V>(self, v: T) -> Self
pub fn set_projects<T, V>(self, v: T) -> Self
Sourcepub fn set_next_page_token<T: Into<String>>(self, v: T) -> Self
pub fn set_next_page_token<T: Into<String>>(self, v: T) -> Self
Sets the value of next_page_token.
Example
let x = SearchProjectsResponse::new().set_next_page_token("example");Trait Implementations
Sourceimpl Clone for SearchProjectsResponse
impl Clone for SearchProjectsResponse
Sourcefn clone(&self) -> SearchProjectsResponse
fn clone(&self) -> SearchProjectsResponse
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for SearchProjectsResponse
impl Debug for SearchProjectsResponse
Sourceimpl Default for SearchProjectsResponse
impl Default for SearchProjectsResponse
Sourcefn default() -> SearchProjectsResponse
fn default() -> SearchProjectsResponse
Sourceimpl Message for SearchProjectsResponse
impl Message for SearchProjectsResponse
Sourceimpl PartialEq for SearchProjectsResponse
impl PartialEq for SearchProjectsResponse
impl StructuralPartialEq for SearchProjectsResponse